@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.15"
+__version__ = "1.0.16"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -28,7 +28,7 @@ from qubell.api.private import exceptions
 
 class QubellPlatform(object):
 
-    def __init__(self, auth, context=None):
+    def __init__(self, auth=None, context=None):
         self.organizations = []
         self.auth = context | auth
         self.user = self.auth.user
